Rename static analyzer namespace 'GR' to 'ento'.

git-svn-id: https://llvm.org/svn/llvm-project/cfe/trunk@122492 91177308-0d34-0410-b5e6-96231b3b80d8
diff --git a/lib/GR/SimpleConstraintManager.cpp b/lib/GR/SimpleConstraintManager.cpp
index 83e7955..f0d50da 100644
--- a/lib/GR/SimpleConstraintManager.cpp
+++ b/lib/GR/SimpleConstraintManager.cpp
@@ -19,7 +19,7 @@
 
 namespace clang {
 
-namespace GR {
+namespace ento {
 
 SimpleConstraintManager::~SimpleConstraintManager() {}
 
@@ -298,6 +298,6 @@
   } // end switch
 }
 
-} // end of namespace GR
+} // end of namespace ento
 
 } // end of namespace clang